@@ -286,6 +286,11 @@ move_handler(GtkWidget *widget, GtkSheetRange *old_range,
 
 }
 
+void alarm(GtkWidget *widget, gint row, gint col, gpointer data)
+{
+ printf("ACTIVATE CELL: %d %d\n",row,col);
+}
+
 void
 build_example1(GtkWidget *widget)
 {
@@ -295,7 +300,6 @@ build_example1(GtkWidget *widget)
  gint i;
 
  sheet=GTK_SHEET(widget);
-
  gtk_sheet_set_cell(sheet, 0,0, GTK_JUSTIFY_LEFT,
                     "You can drag & drop the selection");
  gtk_sheet_set_cell(sheet, 1,0, GTK_JUSTIFY_LEFT,
@@ -335,7 +339,12 @@ build_example1(GtkWidget *widget)
                     "move_range",
                     (GtkSignalFunc) move_handler, 
                     NULL);
-
+/*
+ gtk_signal_connect(GTK_OBJECT(sheet),
+                    "activate_cell",
+                    (GtkSignalFunc) alarm, 
+                    NULL);
+*/
 }
 
 
@@ -348,6 +357,7 @@ build_example2(GtkWidget *widget)
  
  sheet=GTK_SHEET(widget);
 
+ gtk_sheet_hide_row_titles(sheet);
  range.row0=0;
  range.rowi=2;
  range.col0=0;
