@@ -72,6 +72,8 @@ enum
   SHEET_COLUMN_FROZEN   = 1 << 9,  /* set cols to be resizeable */
   SHEET_AUTORESIZE      = 1 << 10,  /* resize column if text width is great than column width */
   SHEET_ADJUST_TEXT     = 1 << 11, /* fix text to column width */
+  SHEET_ROW_TITLES_VISIBLE = 1 << 12,
+  SHEET_COL_TITLES_VISIBLE = 1 << 13,
 }; 
 
 #define GTK_SHEET(obj)          GTK_CHECK_CAST (obj, gtk_sheet_get_type (), GtkSheet)
@@ -94,6 +96,8 @@ enum
 #define GTK_SHEET_COLUMN_FROZEN(sheet)   (GTK_SHEET_FLAGS (sheet) & SHEET_COLUMN_FROZEN)
 #define GTK_SHEET_AUTORESIZE(sheet)   (GTK_SHEET_FLAGS (sheet) & SHEET_AUTORESIZE)
 #define GTK_SHEET_ADJUST_TEXT(sheet)   (GTK_SHEET_FLAGS (sheet) & SHEET_ADJUST_TEXT)
+#define GTK_SHEET_ROW_TITLES_VISIBLE(sheet)   (GTK_SHEET_FLAGS (sheet) & SHEET_ROW_TITLES_VISIBLE)
+#define GTK_SHEET_COL_TITLES_VISIBLE(sheet)   (GTK_SHEET_FLAGS (sheet) & SHEET_COL_TITLES_VISIBLE)
 
 typedef struct _GtkSheet GtkSheet;
 typedef struct _GtkSheetClass GtkSheetClass;
@@ -407,6 +411,16 @@ gtk_sheet_moveto (GtkSheet * sheet,
 	          gfloat row_align,
                   gfloat col_align);
 
+/* show/hide column/row titles window */
+void
+gtk_sheet_show_column_titles(GtkSheet *sheet);
+void
+gtk_sheet_show_row_titles(GtkSheet *sheet);
+void
+gtk_sheet_hide_column_titles(GtkSheet *sheet);
+void
+gtk_sheet_hide_row_titles(GtkSheet *sheet);
+
 /* set column button sensitivity. If sensitivity is TRUE it responds selecting  
  * the corresponding column, otherwise it acts as a title */
  void 
